==> openshift-model-hive-5.12.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/HiveConfigConditionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HiveConfigConditionBuilder extends io.fabric8.openshift.api.model.hive.v1.HiveConfigConditionFluentImpl<io.fabric8.openshift.api.model.hive.v1.HiveConfigConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.HiveConfigCondition,io.fabric8.openshift.api.model.hive.v1.HiveConfigConditionBuilder>{
  public HiveConfigConditionBuilder() {
    this(false);
  }
  public HiveConfigConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new HiveConfigCondition(), validationEnabled);
  }
  public HiveConfigConditionBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfigConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public HiveConfigConditionBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfigConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HiveConfigCondition(), validationEnabled);
  }
  public HiveConfigConditionBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfigConditionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.HiveConfigCondition instance) {
    this(fluent, instance, false);
  }
  public HiveConfigConditionBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfigConditionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.HiveConfigCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HiveConfigConditionBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfigCondition instance) {
    this(instance,false);
  }
  public HiveConfigConditionBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfigCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.HiveConfigConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.HiveConfigCondition build() {
    HiveConfigCondition buildable = new HiveConfigCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HiveConfigConditionBuilder that = (HiveConfigConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/HiveConfigConditionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HiveConfigConditionBuilder extends HiveConfigConditionFluentImpl<HiveConfigConditionBuilder> implements VisitableBuilder<HiveConfigCondition,HiveConfigConditionBuilder>{
  public HiveConfigConditionBuilder() {
    this(false);
  }
  public HiveConfigConditionBuilder(Boolean validationEnabled) {
    this(new HiveConfigCondition(), validationEnabled);
  }
  public HiveConfigConditionBuilder(HiveConfigConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public HiveConfigConditionBuilder(HiveConfigConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HiveConfigCondition(), validationEnabled);
  }
  public HiveConfigConditionBuilder(HiveConfigConditionFluent<?> fluent,HiveConfigCondition instance) {
    this(fluent, instance, false);
  }
  public HiveConfigConditionBuilder(HiveConfigConditionFluent<?> fluent,HiveConfigCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HiveConfigConditionBuilder(HiveConfigCondition instance) {
    this(instance,false);
  }
  public HiveConfigConditionBuilder(HiveConfigCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  HiveConfigConditionFluent<?> fluent;
  Boolean validationEnabled;
  public HiveConfigCondition build() {
    HiveConfigCondition buildable = new HiveConfigCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
